@@ -12,6 +12,13 @@ def test_empty(compress):
   assert mbuf.validate()
   assert mbuf.compress == compress
 
+  try:
+    mbuf[1000]
+    assert False
+  except KeyError:
+    pass
+
+
 @pytest.mark.parametrize("compress", (None, "gzip", "br", "zstd"))
 def test_full(compress):
   data = { 
@@ -26,9 +33,20 @@ def test_full(compress):
 
   for key in data:
     assert data[key] == mbuf[key]
+    assert data[key] == mbuf.get(key)
+    assert key in mbuf
 
   assert data == mbuf.todict()
 
+  for i in range(2000):
+    if i not in data:
+      assert i not in mbuf
+      try:
+        mbuf[i]
+        assert False
+      except KeyError:
+        pass
+
   mbuf.validate()
 
   assert len(mbuf.buffer) > HEADER_LENGTH
\ No newline at end of file
